@@ -3,7 +3,6 @@ package main
 import (
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"strings"
 	"talisman/prompt"
@@ -42,6 +41,20 @@ fileignoreconfig:
   checksum: 1db800b79e6e9695adc451f77be974dc47bcd84d42873560d7767bfca30db8b1
   ignore_detectors: []
 `
+const invalidTalismanRC = `
+fileignoreconfig:
+- filename:
+private.pem
+  checksum: checksum_value
+  ignore_detectors: []
+  `
+
+const talismanRCForHelloTxtFile = `
+fileignoreconfig:
+- filename: hello.txt
+  checksum: edf37f1d33525d1710c3f5dc3437778c483def1d2e98b5a3495fc627eb1be588
+  ignore_detectors: []
+`
 
 func init() {
 	git_testing.Logger = logrus.WithField("Environment", "Debug")
@@ -49,21 +62,21 @@ func init() {
 }
 
 func TestNotHavingAnyOutgoingChangesShouldNotFail(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		assert.Equal(t, 0, runTalismanInPrePushMode(git), "Expected run() to return 0 if no input is available on stdin. This happens when there are no outgoing changes")
 	})
 }
 
 func TestAddingSimpleFileShouldExitZero(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		assert.Equal(t, 0, runTalismanInPrePushMode(git), "Expected run() to return 0 and pass as no suspicious files are in the repo")
 	})
 }
 
 func TestAddingSecretKeyShouldExitOne(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("private.pem", "secret")
 		git.AddAndcommit("*", "add private key")
@@ -74,7 +87,7 @@ func TestAddingSecretKeyShouldExitOne(t *testing.T) {
 
 func TestAddingSecretKeyAsFileContentShouldExitOne(t *testing.T) {
 
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("contains_keys.properties", awsAccessKeyIDExample)
 		git.AddAndcommit("*", "add private key as content")
@@ -84,7 +97,7 @@ func TestAddingSecretKeyAsFileContentShouldExitOne(t *testing.T) {
 }
 
 func TestAddingSecretKeyShouldExitZeroIfPEMFileIsIgnored(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("private.pem", "secret")
 		git.CreateFileWithContents(".talismanrc", talismanRCDataWithFileNameAndCorrectChecksum)
@@ -94,20 +107,8 @@ func TestAddingSecretKeyShouldExitZeroIfPEMFileIsIgnored(t *testing.T) {
 	})
 }
 
-func TestAddingSecretKeyShouldExitOneIfPEMFileIsPresentInTheGitHistory(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
-		options.Scan = false
-
-		git.SetupBaselineFiles("simple-file")
-		git.CreateFileWithContents("private.pem", "secret")
-		git.CreateFileWithContents(".talismanrc", talismanRCDataWithFileNameAndCorrectChecksum)
-		git.AddAndcommit("private.pem", "add private key")
-		assert.Equal(t, 0, runTalismanInPrePushMode(git), "Expected run() to return 0 and pass as pem file was ignored")
-	})
-}
-
 func TestScanningSimpleFileShouldExitZero(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Scan = false
 
 		git.SetupBaselineFiles("simple-file")
@@ -116,7 +117,7 @@ func TestScanningSimpleFileShouldExitZero(t *testing.T) {
 }
 
 func TestChecksumCalculatorShouldExitOne(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Checksum = "*txt1"
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("private.pem", "secret")
@@ -128,7 +129,7 @@ func TestChecksumCalculatorShouldExitOne(t *testing.T) {
 }
 
 func TestShouldExitOneWhenSecretIsCommitted(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Debug = false
 		options.GitHook = PreCommit
 		options.Scan = false
@@ -140,7 +141,7 @@ func TestShouldExitOneWhenSecretIsCommitted(t *testing.T) {
 }
 
 func TestShouldExitZeroWhenNonSecretIsCommittedButFileContainsSecretPreviously(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Debug = false
 		options.GitHook = PreCommit
 		git.SetupBaselineFiles("simple-file")
@@ -156,7 +157,7 @@ func TestShouldExitZeroWhenNonSecretIsCommittedButFileContainsSecretPreviously(t
 
 // Need to work on this test case as talismanrc does  not yet support comments
 func TestAddingSecretKeyShouldExitZeroIfPEMFilesAreIgnoredAndCommented(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("private.pem", "secret")
 		git.CreateFileWithContents(".talismanrc", talismanRCDataWithIgnoreDetectorWithFilename)
@@ -167,7 +168,7 @@ func TestAddingSecretKeyShouldExitZeroIfPEMFilesAreIgnoredAndCommented(t *testin
 }
 
 func TestAddingSecretKeyShouldExitOneIfTheyContainBadContentButOnlyFilenameDetectorWasIgnored(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("private.pem", awsAccessKeyIDExample)
 		git.CreateFileWithContents(".talismanrc", talismanRCDataWithIgnoreDetectorWithFilename)
@@ -178,7 +179,7 @@ func TestAddingSecretKeyShouldExitOneIfTheyContainBadContentButOnlyFilenameDetec
 }
 
 func TestAddingSecretKeyShouldExitZeroIfFileIsWithinConfiguredScope(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("glide.lock", awsAccessKeyIDExample)
 		git.CreateFileWithContents("glide.yaml", awsAccessKeyIDExample)
@@ -190,7 +191,7 @@ func TestAddingSecretKeyShouldExitZeroIfFileIsWithinConfiguredScope(t *testing.T
 }
 
 func TestAddingSecretKeyShouldExitOneIfFileIsNotWithinConfiguredScope(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("danger.pem", awsAccessKeyIDExample)
 		git.CreateFileWithContents("glide.yaml", awsAccessKeyIDExample)
@@ -202,7 +203,7 @@ func TestAddingSecretKeyShouldExitOneIfFileIsNotWithinConfiguredScope(t *testing
 }
 
 func TestAddingSecretKeyShouldExitOneIfFileNameIsSensitiveButOnlyFilecontentDetectorWasIgnored(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("private.pem", awsAccessKeyIDExample)
 		git.CreateFileWithContents(".talismanrc", talismanRCDataWithIgnoreDetectorWithFilecontent)
@@ -213,7 +214,7 @@ func TestAddingSecretKeyShouldExitOneIfFileNameIsSensitiveButOnlyFilecontentDete
 }
 
 func TestStagingSecretKeyShouldExitOneWhenPreCommitFlagIsSet(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("private.pem", "secret")
 		git.Add("*")
@@ -226,7 +227,7 @@ func TestStagingSecretKeyShouldExitOneWhenPreCommitFlagIsSet(t *testing.T) {
 }
 
 func TestPatternFindsSecretKey(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Debug = false
 		options.Pattern = "./*.*"
 
@@ -238,7 +239,7 @@ func TestPatternFindsSecretKey(t *testing.T) {
 }
 
 func TestPatternFindsNestedSecretKey(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Debug = false
 		options.Pattern = "./**/*.*"
 
@@ -250,7 +251,7 @@ func TestPatternFindsNestedSecretKey(t *testing.T) {
 }
 
 func TestPatternFindsSecretInNestedFile(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Debug = false
 		options.Pattern = "./**/*.*"
 
@@ -261,27 +262,65 @@ func TestPatternFindsSecretInNestedFile(t *testing.T) {
 	})
 }
 
-func TestIgnoreHistoryDoesNotDetectRemovedSecrets(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+func TestFilesWithSameNameWithinRepositoryAreHandledAsSeparateFiles(t *testing.T) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
+		git.SetupBaselineFiles("simple-file", "some-dir/hello.txt")
+		git.CreateFileWithContents("hello.txt", awsAccessKeyIDExample)
+		git.AddAndcommit("*", "Start of Scan before talismanrc")
+		assert.Equal(t, 1, runTalismanInPrePushMode(git), "Expected run() to return 1 since secret is detected in hello")
+		git.CreateFileWithContents(".talismanrc", talismanRCForHelloTxtFile)
+
+		git.AppendFileContent("some-dir/hello.txt", "More safe content")
+		assert.Equal(t, 0, runTalismanInPrePushMode(git), "Expected run() to return 0 since hello checksum is added to fileignoreconfig in talismanrc")
+		git.AddAndcommit("some-dir/hello.txt", "Start of second scan")
+		assert.Equal(t, 0, runTalismanInPrePushMode(git), "Expected run() to return 0 since hello in subfolder was only changed")
+		git.AppendFileContent("hello.txt", "More safe content in unsafe file")
+		git.AddAndcommit("hello.txt", "Start of third scan - new hash is required")
+		assert.Equal(t, 1, runTalismanInPrePushMode(git), "Expected run() to return 1 since hello checksum is changed")
+	})
+}
+
+func TestScan(t *testing.T) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Debug = false
 		options.Pattern = "./**/*.*"
 		options.Scan = true
-		options.IgnoreHistory = true
 
 		git.SetupBaselineFiles("simple-file")
 		git.CreateFileWithContents("some-dir/should-not-be-included.txt", awsAccessKeyIDExample)
 		git.AddAndcommit("*", "Initial Commit")
-		git.RemoveFile("some-dir/should-not-be-included.txt")
-		git.AddAndcommit("*", "Removed secret")
 		git.CreateFileWithContents("some-dir/should-be-included.txt", "safeContents")
 		git.AddAndcommit("*", "Start of Scan")
+		git.RemoveFile("some-dir/should-not-be-included.txt")
+		git.AddAndcommit("*", "Removed secret")
 
-		assert.Equal(t, 0, runTalisman(git), "Expected run() to return 0 since secret was removed from head")
+		t.Run("Detects removed secrets", func(t *testing.T) {
+			options.IgnoreHistory = false
+			assert.Equal(t, 1, runTalisman(git), "Expected run() to return 1 because of removed secret in history")
+		})
+
+		t.Run("Does not detect removed secrets when ignoring history", func(t *testing.T) {
+			options.IgnoreHistory = true
+			assert.Equal(t, 0, runTalisman(git), "Expected run() to return 0 since secret was removed from head")
+		})
+	})
+}
+
+func TestScanDetectsIgnoredSecret(t *testing.T) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
+		options.Scan = true
+		options.IgnoreHistory = false
+
+		git.SetupBaselineFiles("simple-file")
+		git.CreateFileWithContents("private.pem", "secret")
+		git.CreateFileWithContents(".talismanrc", talismanRCDataWithFileNameAndCorrectChecksum)
+		git.AddAndcommit("private.pem", "add private key")
+		assert.Equal(t, 1, runTalisman(git), "Expected run() to return 1 because ignores aren't check when scanning history")
 	})
 }
 
 func TestIgnoreHistoryDetectsExistingIssuesOnHead(t *testing.T) {
-	withNewTmpGitRepo(func(git *git_testing.GitTesting) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
 		options.Debug = false
 		options.Pattern = "./**/*.*"
 		options.Scan = true
@@ -297,6 +336,64 @@ func TestIgnoreHistoryDetectsExistingIssuesOnHead(t *testing.T) {
 	})
 }
 
+func TestTalismanFailsIfTalismanrcIsInvalidYamlInPrePushMode(t *testing.T) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
+		git.SetupBaselineFiles("simple-file")
+		git.CreateFileWithContents(".talismanrc", invalidTalismanRC)
+		git.AddAndcommit("*", "Incorrect Talismanrc commit")
+
+		assert.Equal(t, 1, runTalismanInPrePushMode(git), "Expected run() to return 1 and fails as talismanrc is invalid")
+	})
+}
+
+func TestTalismanFailsIfTalismanrcIsInvalidYamlInPreCommitMode(t *testing.T) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
+		options.Debug = true
+		options.GitHook = PreCommit
+		git.SetupBaselineFiles("simple-file")
+		git.CreateFileWithContents(".talismanrc", invalidTalismanRC)
+		git.AddAndcommit("*", "Incorrect Talismanrc commit")
+
+		assert.Equal(t, 1, runTalisman(git), "Expected run() to return 0 and pass as pem file was ignored")
+	})
+}
+
+func TestTalismanFailsIfTalismanrcIsInvalidYamlInScanMode(t *testing.T) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
+		options.Debug = true
+		options.Scan = true
+		git.SetupBaselineFiles("simple-file")
+		git.CreateFileWithContents(".talismanrc", invalidTalismanRC)
+		git.AddAndcommit("*", "Incorrect Talismanrc commit")
+
+		assert.Equal(t, 1, runTalisman(git), "Expected run() to return 0 and pass as pem file was ignored")
+	})
+}
+
+func TestTalismanFailsIfTalismanrcIsInvalidYamlInScanWithHTMLMode(t *testing.T) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
+		options.Debug = true
+		options.ScanWithHtml = true
+		git.SetupBaselineFiles("simple-file")
+		git.CreateFileWithContents(".talismanrc", invalidTalismanRC)
+		git.AddAndcommit("*", "Incorrect Talismanrc commit")
+
+		assert.Equal(t, 1, runTalisman(git), "Expected run() to return 0 and pass as pem file was ignored")
+	})
+}
+
+func TestTalismanFailsIfTalismanrcIsInvalidYamlInPatternMode(t *testing.T) {
+	git_testing.DoInTempGitRepo(func(git *git_testing.GitTesting) {
+		options.Debug = false
+		options.Pattern = "./*.*"
+
+		git.SetupBaselineFiles("simple-file")
+		git.CreateFileWithContents(".talismanrc", invalidTalismanRC)
+
+		assert.Equal(t, 1, runTalisman(git), "Expected run() to return 1 and fail as pem file was present in the repo")
+	})
+}
+
 func runTalismanInPrePushMode(git *git_testing.GitTesting) int {
 	options.Debug = true
 	options.GitHook = PrePush
@@ -305,7 +402,7 @@ func runTalismanInPrePushMode(git *git_testing.GitTesting) int {
 
 func runTalisman(git *git_testing.GitTesting) int {
 	wd, _ := os.Getwd()
-	os.Chdir(git.GetRoot())
+	os.Chdir(git.Root())
 	defer func() { os.Chdir(wd) }()
 	prompter := prompt.NewPrompt()
 	promptContext := prompt.NewPromptContext(false, prompter)
@@ -315,27 +412,6 @@ func runTalisman(git *git_testing.GitTesting) int {
 	return run(promptContext)
 }
 
-type Operation func(dirName string)
-
-func withNewTmpDirNamed(dirName string, operation Operation) {
-	path, err := ioutil.TempDir(os.TempDir(), dirName)
-	if err != nil {
-		panic(err)
-	}
-	operation(path)
-}
-
-type GitOperation func(*git_testing.GitTesting)
-
-func withNewTmpGitRepo(doGitOperation GitOperation) {
-	withNewTmpDirNamed("talisman-acceptance-test", func(gitPath string) {
-		gt := git_testing.Init(gitPath)
-		gt.RemoveHooks()
-		doGitOperation(gt)
-		os.RemoveAll(gitPath)
-	})
-}
-
 func mockStdIn(oldSha string, newSha string) io.Reader {
 	return strings.NewReader(fmt.Sprintf("master %s master %s\n", newSha, oldSha))
 }
