@@ -2,6 +2,7 @@ package main
 
 import (
 	"fmt"
+	"os"
 	"talisman/detector"
 	"talisman/detector/helpers"
 	"talisman/detector/severity"
@@ -10,27 +11,32 @@ import (
 	"talisman/talismanrc"
 )
 
-//runner represents a single run of the validations for a given commit range
+// runner represents a single run of the validations for a given commit range
 type runner struct {
 	additions []gitrepo.Addition
 	results   *helpers.DetectionResults
 	mode      string
 }
 
-//NewRunner returns a new runner.
+// NewRunner returns a new runner.
 func NewRunner(additions []gitrepo.Addition, mode string) *runner {
 	return &runner{
 		additions: additions,
-		results:   helpers.NewDetectionResults(talismanrc.HookMode),
+		results:   helpers.NewDetectionResults(),
 		mode:      mode,
 	}
 }
 
-//Run will validate the commit range for errors and return either COMPLETED_SUCCESSFULLY or COMPLETED_WITH_ERRORS
+// Run will validate the commit range for errors and return either COMPLETED_SUCCESSFULLY or COMPLETED_WITH_ERRORS
 func (r *runner) Run(tRC *talismanrc.TalismanRC, promptContext prompt.PromptContext) int {
+	wd, _ := os.Getwd()
+	repo := gitrepo.RepoLocatedAt(wd)
+	ie := helpers.BuildIgnoreEvaluator(r.mode, tRC, repo)
+
 	setCustomSeverities(tRC)
-	additionsToScan := tRC.FilterAdditions(r.additions)
-	detector.DefaultChain(tRC, r.mode).Test(additionsToScan, tRC, r.results)
+	additionsToScan := tRC.RemoveScopedFiles(r.additions)
+
+	detector.DefaultChain(tRC, ie).Test(additionsToScan, tRC, r.results)
 	r.printReport(promptContext)
 	exitStatus := r.exitStatus()
 	return exitStatus
