@@ -19,10 +19,10 @@ func NewFileSizeDetector(size int) detector.Detector {
 	return FileSizeDetector{size}
 }
 
-func (fd FileSizeDetector) Test(comparator helpers.ChecksumCompare, currentAdditions []gitrepo.Addition, ignoreConfig *talismanrc.TalismanRC, result *helpers.DetectionResults, additionCompletionCallback func()) {
+func (fd FileSizeDetector) Test(comparator helpers.IgnoreEvaluator, currentAdditions []gitrepo.Addition, ignoreConfig *talismanrc.TalismanRC, result *helpers.DetectionResults, additionCompletionCallback func()) {
 	largeFileSizeSeverity := severity.SeverityConfiguration["LargeFileSize"]
 	for _, addition := range currentAdditions {
-		if ignoreConfig.Deny(addition, "filesize") || comparator.IsScanNotRequired(addition) {
+		if comparator.ShouldIgnore(addition, "filesize") {
 			log.WithFields(log.Fields{
 				"filePath": addition.Path,
 			}).Info("Ignoring addition as it was specified to be ignored.")
