@@ -36,8 +36,8 @@ type match struct {
 	detections []DetectionsWithSeverity
 }
 
-//Test tests the contents of the Additions to ensure that they don't look suspicious
-func (detector PatternDetector) Test(comparator helpers.ChecksumCompare, currentAdditions []gitrepo.Addition, ignoreConfig *talismanrc.TalismanRC, result *helpers.DetectionResults, additionCompletionCallback func()) {
+// Test tests the contents of the Additions to ensure that they don't look suspicious
+func (detector PatternDetector) Test(comparator helpers.IgnoreEvaluator, currentAdditions []gitrepo.Addition, ignoreConfig *talismanrc.TalismanRC, result *helpers.DetectionResults, additionCompletionCallback func()) {
 	matches := make(chan match, 512)
 	ignoredFilePaths := make(chan gitrepo.FilePath, 512)
 	waitGroup := &sync.WaitGroup{}
@@ -46,11 +46,11 @@ func (detector PatternDetector) Test(comparator helpers.ChecksumCompare, current
 		go func(addition gitrepo.Addition) {
 			defer waitGroup.Done()
 			defer additionCompletionCallback()
-			if ignoreConfig.Deny(addition, "filecontent") || comparator.IsScanNotRequired(addition) {
+			if comparator.ShouldIgnore(addition, "filecontent") {
 				ignoredFilePaths <- addition.Path
 				return
 			}
-			detections := detector.secretsPattern.check(ignoreConfig.FilterAllowedPatternsFromAddition(addition), ignoreConfig.Threshold)
+			detections := detector.secretsPattern.check(ignoreConfig.RemoveAllowedPatterns(addition), ignoreConfig.Threshold)
 			matches <- match{name: addition.Name, path: addition.Path, detections: detections, commits: addition.Commits}
 		}(addition)
 	}
@@ -88,7 +88,7 @@ func (detector PatternDetector) processMatch(match match, result *helpers.Detect
 	for _, detectionWithSeverity := range match.detections {
 		for _, detection := range detectionWithSeverity.detections {
 			if detection != "" {
-				if string(match.name) == talismanrc.DefaultRCFileName || !detectionWithSeverity.severity.ExceedsThreshold(threshold) {
+				if string(match.name) == talismanrc.RCFileName || !detectionWithSeverity.severity.ExceedsThreshold(threshold) {
 					log.WithFields(log.Fields{
 						"filePath": match.path,
 						"pattern":  detection,
@@ -106,7 +106,7 @@ func (detector PatternDetector) processMatch(match match, result *helpers.Detect
 	}
 }
 
-//NewPatternDetector returns a PatternDetector that tests Additions against the pre-configured patterns
+// NewPatternDetector returns a PatternDetector that tests Additions against the pre-configured patterns
 func NewPatternDetector(custom []talismanrc.PatternString) *PatternDetector {
 	matcher := NewPatternMatcher(detectorPatterns)
 	for _, pattern := range custom {
