@@ -7,20 +7,23 @@ import (
 	"talisman/detector/severity"
 	"talisman/gitrepo"
 	"talisman/talismanrc"
-	"talisman/utility"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 )
 
 var talismanRC = &talismanrc.TalismanRC{}
-var defaultChecksumCompare = helpers.NewChecksumCompare(nil, utility.MakeHasher("default", "."), talismanRC)
+var defaultIgnoreEvaluator = helpers.BuildIgnoreEvaluator("default", talismanRC, gitrepo.RepoLocatedAt("."))
 var dummyCallback = func() {}
 
 var (
 	customPatterns []talismanrc.PatternString
 )
 
+func ignoreEvaluatorWithTalismanRC(tRC *talismanrc.TalismanRC) helpers.IgnoreEvaluator {
+	return helpers.BuildIgnoreEvaluator("default", tRC, gitrepo.RepoLocatedAt("."))
+}
+
 func TestShouldDetectPasswordPatterns(t *testing.T) {
 	filename := "secret.txt"
 	values := [7]string{"password", "secret", "key", "pwd", "pass", "pword", "passphrase"}
@@ -30,8 +33,8 @@ func TestShouldDetectPasswordPatterns(t *testing.T) {
 		shouldPassDetectionOfSecretPattern(filename, []byte("."+values[i]+"=randomStringGoesHere}"), t)
 		shouldPassDetectionOfSecretPattern(filename, []byte(":"+values[i]+" randomStringGoesHere"), t)
 		shouldPassDetectionOfSecretPattern(filename, []byte(values[i]+" ,\"randomStringGoesHere\""), t)
-		shouldPassDetectionOfSecretPattern(filename, []byte("'" + values[i]+"' ,\"randomStringGoesHere\""), t)
-		shouldPassDetectionOfSecretPattern(filename, []byte("\"" + values[i]+"\" ,\"randomStringGoesHere\""), t)
+		shouldPassDetectionOfSecretPattern(filename, []byte("'"+values[i]+"' ,\"randomStringGoesHere\""), t)
+		shouldPassDetectionOfSecretPattern(filename, []byte("\""+values[i]+"\" ,\"randomStringGoesHere\""), t)
 		shouldPassDetectionOfSecretPattern(filename,
 			[]byte("\"SERVER_"+strings.ToUpper(values[i])+"\" : UnsafeString"),
 			t)
@@ -62,60 +65,59 @@ func TestShouldDetectPasswordPatterns(t *testing.T) {
 	shouldFailDetectionOfSecretPattern(filename, []byte(`random=12345678)`), t)
 }
 
-func TestShouldIgnorePasswordPatterns(t *testing.T) {
-	results := helpers.NewDetectionResults(talismanrc.HookMode)
+func TestShouldIgnorePasswordPatternsIfChecksumMatches(t *testing.T) {
+	results := helpers.NewDetectionResults()
 	content := []byte("\"password\" : UnsafePassword")
 	filename := "secret.txt"
 	additions := []gitrepo.Addition{gitrepo.NewAddition(filename, content)}
-	fileIgnoreConfig := &talismanrc.FileIgnoreConfig{
+	fileIgnoreConfig := talismanrc.FileIgnoreConfig{
 		FileName:        filename,
 		Checksum:        "833b6c24c8c2c5c7e1663226dc401b29c005492dc76a1150fc0e0f07f29d4cc3",
 		IgnoreDetectors: []string{"filecontent"},
 		AllowedPatterns: []string{}}
-	ignores := &talismanrc.TalismanRC{IgnoreConfigs: []talismanrc.IgnoreConfig{fileIgnoreConfig}}
+	ignores := &talismanrc.TalismanRC{FileIgnoreConfig: []talismanrc.FileIgnoreConfig{fileIgnoreConfig}}
 
-	NewPatternDetector(customPatterns).Test(defaultChecksumCompare, additions, ignores, results, dummyCallback)
+	NewPatternDetector(customPatterns).Test(ignoreEvaluatorWithTalismanRC(ignores), additions, ignores, results, dummyCallback)
 
-	assert.True(t, results.Successful(), "Expected file %s to be ignored by pattern", filename)
+	assert.True(t, results.Successful(), "Expected file %s to be ignored because checksum matches", filename)
 }
 
 func TestShouldIgnoreAllowedPattern(t *testing.T) {
-	results := helpers.NewDetectionResults(talismanrc.HookMode)
+	results := helpers.NewDetectionResults()
 	content := []byte("\"key\" : \"This is an allowed keyword\"\npassword=y0uw1lln3v3rgu3ssmyP@55w0rd")
 	filename := "allowed_pattern.txt"
 	additions := []gitrepo.Addition{gitrepo.NewAddition(filename, content)}
-	fileIgnoreConfig := &talismanrc.FileIgnoreConfig{
+	fileIgnoreConfig := talismanrc.FileIgnoreConfig{
 		FileName: filename, Checksum: "",
 		IgnoreDetectors: []string{},
 		AllowedPatterns: []string{"key"}}
 	ignores := &talismanrc.TalismanRC{
-		IgnoreConfigs:   []talismanrc.IgnoreConfig{fileIgnoreConfig},
-		AllowedPatterns: []*regexp.Regexp{regexp.MustCompile("password")}}
+		FileIgnoreConfig: []talismanrc.FileIgnoreConfig{fileIgnoreConfig},
+		AllowedPatterns:  []*talismanrc.Pattern{{Regexp: regexp.MustCompile("password")}}}
 
-	NewPatternDetector(customPatterns).Test(defaultChecksumCompare, additions, ignores, results, dummyCallback)
+	NewPatternDetector(customPatterns).Test(defaultIgnoreEvaluator, additions, ignores, results, dummyCallback)
 
 	assert.True(t,
 		results.Successful(),
 		"Expected keywords %v %v to be ignored by Talisman", fileIgnoreConfig.AllowedPatterns, ignores.AllowedPatterns)
 }
 func TestShouldOnlyWarnSecretPatternIfBelowThreshold(t *testing.T) {
-	results := helpers.NewDetectionResults(talismanrc.HookMode)
+	results := helpers.NewDetectionResults()
 	content := []byte(`password=UnsafeString`)
 	filename := "secret.txt"
 	additions := []gitrepo.Addition{gitrepo.NewAddition(filename, content)}
 	talismanRCWithThreshold := &talismanrc.TalismanRC{Threshold: severity.High}
-	checksumCompare := helpers.NewChecksumCompare(nil, utility.MakeHasher("default", "."), talismanRCWithThreshold)
 
-	NewPatternDetector(customPatterns).Test(checksumCompare, additions, talismanRCWithThreshold, results, dummyCallback)
+	NewPatternDetector(customPatterns).Test(ignoreEvaluatorWithTalismanRC(talismanRCWithThreshold), additions, talismanRCWithThreshold, results, dummyCallback)
 
 	assert.False(t, results.HasFailures(), "Expected file %s to not have failures", filename)
 	assert.True(t, results.HasWarnings(), "Expected file %s to have warnings", filename)
 }
 
 func DetectionOfSecretPattern(filename string, content []byte) (*helpers.DetectionResults, []gitrepo.Addition, string) {
-	results := helpers.NewDetectionResults(talismanrc.HookMode)
+	results := helpers.NewDetectionResults()
 	additions := []gitrepo.Addition{gitrepo.NewAddition(filename, content)}
-	NewPatternDetector(customPatterns).Test(defaultChecksumCompare, additions, talismanRC, results, dummyCallback)
+	NewPatternDetector(customPatterns).Test(defaultIgnoreEvaluator, additions, talismanRC, results, dummyCallback)
 	expected := "Potential secret pattern : " + string(content)
 	return results, additions, expected
 }
