@@ -2,7 +2,6 @@ package git_testing
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -10,51 +9,64 @@ import (
 
 	lorem "github.com/drhodes/golorem"
 	"github.com/sirupsen/logrus"
+	"github.com/spf13/afero"
 )
 
 var Logger *logrus.Entry
 
+// GitTesting provides an API for manipulating a git repository during tests
 type GitTesting struct {
-	gitRoot string
+	root string
 }
 
-func Init(gitRoot string) *GitTesting {
+type GitOperation func(*GitTesting)
+
+// DoInTempGitRepo initializes a temporary git repository and executes the provided GitOperation in it
+func DoInTempGitRepo(gitOperation GitOperation) {
+	gt := Init()
+	defer gt.Clean()
+	gitOperation(gt)
+}
+
+// Init creates a GitTesting based in a temporary directory
+func Init() *GitTesting {
+	fs := afero.NewMemMapFs()
+	path, _ := afero.TempDir(fs, afero.GetTempDir(fs, "talisman-test"), "")
+	return initAt(path)
+}
+
+// initAt creates a GitTesting based at the specified path
+func initAt(gitRoot string) *GitTesting {
 	os.MkdirAll(gitRoot, 0777)
 	testingRepo := &GitTesting{gitRoot}
-	output := testingRepo.ExecCommand("git", "init", ".")
+	output := testingRepo.execCommand("git", "init", ".")
 	logrus.Debugf("Git init result %v", string(output))
-	if os.Getenv("CI") != "" {
-		fmt.Println("Setting up git_repo")
-		testingRepo.ExecCommand("git", "config", "--global", "user.email", "talisman-test-user@example.com")
-		testingRepo.ExecCommand("git", "config", "--global", "user.name", "Talisman Test User")
-	}
+	testingRepo.execCommand("git", "config", "user.email", "talisman-test-user@example.com")
+	testingRepo.execCommand("git", "config", "user.name", "Talisman Test User")
+	testingRepo.execCommand("git", "config", "commit.gpgsign", "false")
+	testingRepo.removeHooks()
 	return testingRepo
 }
 
-func (git *GitTesting) GitClone(cloneName string) *GitTesting {
-	result := git.ExecCommand("git", "clone", git.gitRoot, cloneName)
-	Logger.Debugf("Clone result : %s\n", result)
-	Logger.Debugf("GitRoot :%s \t CloneRoot: %s\n", git.gitRoot, cloneName)
-	retval := &GitTesting{cloneName}
-	return retval
+// Clean removes the directory containing the git repository represented by a GitTesting
+func (git *GitTesting) Clean() {
+	os.RemoveAll(git.root)
 }
 
 func (git *GitTesting) SetupBaselineFiles(filenames ...string) {
-	Logger.Debugf("Creating %v in %s\n", filenames, git.gitRoot)
-	git.doInGitRoot(func() {
-		for _, filename := range filenames {
-			git.CreateFileWithContents(filename, lorem.Sentence(8, 10), lorem.Sentence(8, 10))
-		}
-	})
+	Logger.Debugf("Creating %v in %s\n", filenames, git.root)
+	for _, filename := range filenames {
+		git.CreateFileWithContents(filename, lorem.Sentence(8, 10), lorem.Sentence(8, 10))
+	}
 	git.AddAndcommit("*", "initial commit")
 }
 
 func (git *GitTesting) EarliestCommit() string {
-	return git.ExecCommand("git", "rev-list", "--max-parents=0", "HEAD")
+	return git.execCommand("git", "rev-list", "--max-parents=0", "HEAD")
 }
 
 func (git *GitTesting) LatestCommit() string {
-	return git.ExecCommand("git", "rev-parse", "HEAD")
+	return git.execCommand("git", "rev-parse", "HEAD")
 }
 
 func (git *GitTesting) CreateFileWithContents(filePath string, contents ...string) string {
@@ -106,7 +118,7 @@ func (git *GitTesting) FileContents(filePath string) []byte {
 	var result []byte
 	var err error
 	git.doInGitRoot(func() {
-		result, err = ioutil.ReadFile(filePath)
+		result, err = os.ReadFile(filePath)
 		git.die(fmt.Sprintf("when reading file %s", filePath), err)
 	})
 	return result
@@ -118,14 +130,14 @@ func (git *GitTesting) AddAndcommit(fileName string, message string) {
 }
 
 func (git *GitTesting) Add(fileName string) {
-	git.ExecCommand("git", "add", fileName)
+	git.execCommand("git", "add", fileName)
 }
 
 func (git *GitTesting) Commit(fileName string, message string) {
-	git.ExecCommand("git", "commit", "-m", message)
+	git.execCommand("git", "commit", "-m", message)
 }
 
-//GetBlobDetails returns git blob details for a path
+// GetBlobDetails returns git blob details for a path
 func (git *GitTesting) GetBlobDetails(fileName string) string {
 	var output []byte
 	objectHashAndFilename := ""
@@ -145,14 +157,14 @@ func (git *GitTesting) GetBlobDetails(fileName string) string {
 	return objectHashAndFilename
 }
 
-//ExecCommand executes a command with given arguments in the git repo directory
-func (git *GitTesting) ExecCommand(commandName string, args ...string) string {
+// execCommand executes a command with given arguments in the git repo directory
+func (git *GitTesting) execCommand(commandName string, args ...string) string {
 	var output []byte
 	git.doInGitRoot(func() {
 		result := exec.Command(commandName, args...)
 		var err error
 		output, err = result.Output()
-		summaryMessage := fmt.Sprintf("Command: %s %v\nWorkingDirectory: %s\nOutput %s\nError: %v", commandName, args, git.gitRoot, string(output), err)
+		summaryMessage := fmt.Sprintf("Command: %s %v\nWorkingDirectory: %s\nOutput %s\nError: %v", commandName, args, git.root, string(output), err)
 		git.die(summaryMessage, err)
 		Logger.Debug(summaryMessage)
 	})
@@ -171,17 +183,18 @@ func (git *GitTesting) die(msg string, err error) {
 
 func (git *GitTesting) doInGitRoot(operation func()) {
 	wd, _ := os.Getwd()
-	os.Chdir(git.gitRoot)
+	os.Chdir(git.root)
 	defer func() { os.Chdir(wd) }()
 	operation()
 }
 
-//GetRoot returns the root directory of the git-testing repo
-func (git *GitTesting) GetRoot() string {
-	return git.gitRoot
+// Root returns the root directory of the git-testing repo
+func (git *GitTesting) Root() string {
+	return git.root
 }
 
-//RemoveHooks removes all file-system hooks from git-test repo
-func (git *GitTesting) RemoveHooks() {
-	git.ExecCommand("rm", "-rf", ".git/hooks/")
+// removeHooks removes all file-system hooks from git-test repo.
+// We do this to prevent any user-installed hooks from interfering with tests.
+func (git *GitTesting) removeHooks() {
+	git.execCommand("rm", "-rf", ".git/hooks/")
 }
