@@ -3,22 +3,36 @@ package talismanrc
 import (
 	"regexp"
 	"talisman/detector/severity"
+
+	logr "github.com/sirupsen/logrus"
 )
 
 type PatternString string
 
+type Pattern struct {
+	*regexp.Regexp
+}
+
+func (p Pattern) MarshalYAML() (interface{}, error) {
+	return p.String(), nil
+}
+
+func (p *Pattern) UnmarshalYAML(unmarshal func(interface{}) error) error {
+	var s string
+	err := unmarshal(&s)
+	if err != nil {
+		logr.Errorf("Pattern.UmarshalYAML error: %v", err)
+		return err
+	}
+	*p = Pattern{regexp.MustCompile(s)}
+	return nil
+}
+
 type CustomSeverityConfig struct {
 	Detector string            `yaml:"detector"`
 	Severity severity.Severity `yaml:"severity"`
 }
 
-type IgnoreConfig interface {
-	isEffective(string) bool
-	GetFileName() string
-	GetAllowedPatterns() []*regexp.Regexp
-	ChecksumMatches(checksum string) bool
-}
-
 type FileIgnoreConfig struct {
 	FileName        string   `yaml:"filename"`
 	Checksum        string   `yaml:"checksum,omitempty"`
@@ -51,6 +65,10 @@ func (i *FileIgnoreConfig) GetAllowedPatterns() []*regexp.Regexp {
 	return i.compiledPatterns
 }
 
+func IgnoreFileWithChecksum(filename, checksum string) FileIgnoreConfig {
+	return FileIgnoreConfig{FileName: filename, Checksum: checksum}
+}
+
 type ScopeConfig struct {
 	ScopeName string `yaml:"scope"`
 }
